#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2016-04-08
#
# 2023-02-17: moved from ~/local/share/check_mk/web/plugins/wato -> ~7local/lib/check_mk/gui/plugins/wato
#

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
)
from cmk.gui.valuespec import (
    Dictionary,
    FixedValue,
    TextAscii,
    ListChoice,
)

from cmk.gui.plugins.wato.inventory import (
    RulespecGroupInventory,
)


def _valuespec_inv_cdp_cache():
    removecolumns = [
        ('platform_details', 'Neighbour platform details'),
        ('capabilities', 'Capabilites'),
        ('vtp_mgmt_domain', 'VTP domain'),
        ('native_vlan', 'Native VLAN'),
        ('duplex', 'Duplex'),
        ('power_consumption', 'Power level'),
        ('last_change', 'Last Change'),
        ('platform', 'Neighbour Platform')
    ]

    return Dictionary(
        title=_('CDP cache'),
        elements=[
            ('remove_domain',
             FixedValue(
                 True,
                 title=_('Remove domain name from neighbour device name'),
                 totext=_(''),
                 default_value=False,
             )),
            ('domain_name',
             TextAscii(
                 title=_('Specific domain name to remove from neighbour device name'),
                 allow_empty=False,
                 default_value='',
             )),
            ('removecolumns',
             ListChoice(
                 title=_('List of columns to remove'),
                 help=_('information to remove from inventory'),
                 choices=removecolumns,
                 default_value=[],
             )),
            ('use_short_if_name',
             FixedValue(
                 True,
                 title=_('use short interface names (i.e. Gi0/0 for GigabitEthernet0/0)'),
                 totext=_(''),
                 default_value=False,
             )),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupInventory,
        match_type='dict',
        name='inv_parameters:inv_cdp_cache',
        valuespec=_valuespec_inv_cdp_cache,
    ))
